==> faceplatform-0.5.4.tgz: package/request.js <==
const _ = require('lodash');
const request = require('request-promise-native');
const interfaces = require('./interfaces');
const Error = require('./error');
const config = require('./config');

/**
 * resolve or reject the response by the rtn
 */
function RR (resp, passit=true) {
    resp = resp || { rtn: 80000 };
    if (!_.has(resp, 'rtn')) {
        return Promise.resolve(resp);
    } else {
        return resp.rtn == 0 ? Promise.resolve(passit ? resp : undefined) : Promise.reject(Error(resp.rtn, resp.message));
    }
}

/**
 * save session_id
 */
function saveSession (resp) {
    if (resp.session_id) {
        this.debug('this.session_id updated: %s', resp.session_id);
        this.session_id = resp.session_id;
    }
}

/**
 * generate the option to be requested
 */
function wrapOption (option) {
    option = _.clone(option) || {};

    // basic info
    option.uri = this.address + option.uri;
    option.json = true;
    option.timeout = this.request_timeout;

    // set auth info
    option.headers = option.headers || {};
    if (this.session_id) {
        option.headers.session_id = this.session_id;
        option.headers.yt_cluster_id = this.session_id.toString().split('@').pop();
    }

    // if it's the login interface
    if (option.name === 'login' && this.auth && this.auth.name && this.auth.password) {
        option.body = option.body || {};
        option.body.name = this.auth.name;
        option.body.password = require('crypto').createHash('md5').update(this.auth.password).digest('hex');
    }
    delete option.name;

    // set default data
    if (_.isEmpty(option.body) && option.data) {
        option.body = option.data;
    }
    delete option.data;

    // assign data subset
    if (option.sub_data) {
        option.body = option.body || {};
        _.assign(option.body, option.sub_data);
    }
    
    // body as qs
    if (option.body && option.qs) {
        option.qs = option.body;
        delete option.body;
    }
    return option;
}

/**
 * login and udpate session_id
 */
function login () {
    const loginOption = wrapOption.call(this, interfaces.login[this.version]);
    this.debug('requesting option for login: ', JSON.stringify(loginOption));

    return request(loginOption)
        .then(resp => {
            this.debug('login response is: %s', JSON.stringify(resp));
            saveSession.call(this, resp);
            return RR(resp);
        })
        .catch(err => {
            this.debug('error occurs while login, skip it: %s', err.toString());
        });
}

/**
 * request other interfaces
 */
function handleRequest (key, ...args) {
    this.debug('go to next method: %s', key);

    // parse arguments
    let data, callback;
    for (let arg of args) {
        if (_.isFunction(arg)) {
            if (arg.w) {
                data = arg();
            } else {
                callback = arg;
                break;
            }
        } else if (_.isObject(arg)) {
            data = arg;
        }
    }

    let option = _.clone(interfaces[key][this.version]);
    if (!option) {
        this.debug('key %s with version %s is not available', key, this.version);
        throw Error(80101);
    }

    option.body = data || option.body;
    option = wrapOption.call(this, option);
    this.debug('requesting option is %s', JSON.stringify(option));

    const _callback = (err, resp, body) => {
        if (!callback) {
            return ;
        }
        if (err || body.rtn != 0) {
            this.debug('error occurs, calling back with: %s', JSON.stringify(err || body));
            return callback(err || Error(body.rtn, body.message), resp, body);
        }
        this.debug('looks good, calling back with: %s', JSON.stringify(body));
        return callback(err, resp, body);
    };

    return request(option, _callback)
        .then(resp => {
            this.debug('response is: %s', JSON.stringify(resp));
            this._r = resp;
            return RR(resp, false);
        })
        .catch(err => {
            this.debug('error occurs, throwing it from within: %s', err.toString());
            throw err;
        });
};

module.exports = {
    login: login,
    requestHandler: handleRequest
};

==> faceplatform-0.6.1.tgz: package/request.js <==
const _ = require('lodash');
const request = require('request-promise-native');
const interfaces = require('./interfaces');
const Error = require('./error');
const config = require('./config');

/**
 * resolve or reject the response by the rtn
 */
function RR (resp, passit=true) {
    resp = resp || { rtn: 80000 };
    if (!_.has(resp, 'rtn')) {
        return Promise.resolve(resp);
    } else {
        return resp.rtn == 0 ? Promise.resolve(passit ? resp : undefined) : Promise.reject(Error(resp.rtn, resp.message));
    }
}

/**
 * generate the option to be requested
 */
function wrapOption (option) {
    option = _.clone(option) || {};

    // basic info
    option.uri = this.address + option.uri;
    option.json = true;
    option.timeout = this.request_timeout;

    // set auth info
    option.headers = option.headers || {};
    if (this.session_id) {
        option.headers.session_id = this.session_id;
        option.headers.yt_cluster_id = this.session_id.toString().split('@').pop();
    }

    // if it's the login interface
    if (option.name === 'login') {
        option.body = option.body || {};
        option.body.name = this.auth.name;
        option.body.password = this.utils.md5(this.auth.password);
    }
    delete option.name;

    // set default data
    if (_.isEmpty(option.body) && option.data) {
        option.body = option.data;
    }
    delete option.data;

    // assign data subset
    if (option.sub_data) {
        option.body = option.body || {};
        _.assign(option.body, option.sub_data);
    }
    
    // body as qs
    if (option.body && option.qs) {
        option.qs = option.body;
        delete option.body;
    }
    return option;
}

/**
 * login and udpate session_id
 */
function login () {
    const loginOption = wrapOption.call(this, interfaces.login[this.version]);
    this.debug('requesting option for login: ', JSON.stringify(loginOption));

    return request(loginOption)
        .then(resp => {
            this.debug('login response is: %s', JSON.stringify(resp));
            return RR(resp);
        })
        .catch(err => {
            this.debug('error occurs while login, skip it: %s', err.toString());
        });
}

/**
 * request other interfaces
 */
function handleRequest (key, ...args) {
    this.debug('go to next method: %s', key);

    // parse arguments
    let data, callback;
    for (let arg of args) {
        if (_.isFunction(arg)) {
            if (arg.w) {
                data = arg();
            } else {
                callback = arg;
                break;
            }
        } else if (_.isObject(arg)) {
            data = arg;
        }
    }

    let option = _.clone(interfaces[key][this.version]);
    if (!option) {
        this.debug('key %s with version %s is not available', key, this.version);
        throw Error(80101);
    }

    option.body = data || option.body;
    option = wrapOption.call(this, option);
    this.debug('requesting option is %s', JSON.stringify(option));

    const _callback = (err, resp, body) => {
        if (!callback) {
            return ;
        }
        if (err || body.rtn != 0) {
            this.debug('error occurs, calling back with: %s', JSON.stringify(err || body));
            return callback(err || Error(body.rtn, body.message), resp, body);
        }
        this.debug('looks good, calling back with: %s', JSON.stringify(body));
        return callback(err, resp, body);
    };

    return request(option, _callback)
        .then(resp => {
            this.debug('response is: %s', JSON.stringify(resp));
            this._r = resp;
            return RR(resp, false);
        })
        .catch(err => {
            this.debug('error occurs, throwing it from within: %s', err.toString());
            throw err;
        });
};

module.exports = {
    login: login,
    requestHandler: handleRequest
};
